import { useEffect, useReducer } from 'react';
function createReducer() {
    return function (state, action) {
        switch (action.type) {
            case 'set': {
                state.map.set(action.key, action.value);
                break;
            }
            case 'delete': {
                state.map.delete(action.key);
                break;
            }
            case 'clear': {
                state.map.clear();
                break;
            }
            case 'reset': {
                return { map: new Map(action.values) };
            }
            default:
                break;
        }
        return {
            map: state.map,
        };
    };
}
export function useMap(arr = [], deps = []) {
    const [state, dispatch] = useReducer(createReducer(), {
        map: new Map(arr),
    });
    useEffect(() => {
        dispatch({ type: 'reset', values: arr });
    }, deps);
    return {
        get: (key) => state.map.get(key),
        set: function (key, value) {
            dispatch({ type: 'set', key, value });
            return this;
        },
        reset: function (values = []) {
            dispatch({ type: 'reset', values });
            return this;
        },
        delete: (key) => {
            if (!state.map.has(key))
                return false;
            dispatch({ type: 'delete', key });
            return true;
        },
        clear: () => dispatch({ type: 'clear' }),
        forEach: (callback) => state.map.forEach(callback),
        map: function (callback) {
            return [...state.map.entries()].map(callback);
        },
        has: (key) => state.map.has(key),
        entries: () => state.map.entries(),
        values: () => state.map.values(),
        keys: () => state.map.keys(),
        size: state.map.size,
        *[Symbol.iterator]() {
            const iterator1 = state.map[Symbol.iterator]();
            for (const item of iterator1) {
                yield item;
            }
        },
        [Symbol.toStringTag]: state.map[Symbol.toStringTag],
    };
}
//# sourceMappingURL=useMap.js.map